@@ -3,6 +3,9 @@
 #include "qmlapplicationviewer.h"
 #include "windowhelper.h"
 #include "filehandler.h"
+//#include "networkhelper.h"
+//#include "pfomodel.h"
+//#include "QString"
 
 #ifdef HAVE_GLWIDGET
 
@@ -10,23 +13,40 @@
 
 #endif
 
+//ListModel* createPfoModel() {
+//  ListModel *model = new ListModel(new PfoItem, qApp);
+//  QString name = "CPfoModel";
+//  QString feedLink = "xxx";
+//  QString excerpt = "Test";
+//  model->append(new PfoItem(false, false, 0, name, feedLink, excerpt));
+
+//  return model;
+//}
+
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
 
     QmlApplicationViewer viewer;
 
-#ifdef HAVE_GLWIDGET
-    QGLWidget *glWidget = new QGLWidget(&viewer);
-    viewer.setViewport(glWidget);
-#endif
+//#ifdef HAVE_GLWIDGET
+//    QGLWidget *glWidget = new QGLWidget(&viewer);
+//    viewer.setViewport(glWidget);
+//#endif
 
     WindowHelper *windowHelper = new WindowHelper();
     viewer.rootContext()->setContextProperty("windowHelper", windowHelper);
     FileHandler *fileHandler = new FileHandler();
     viewer.rootContext()->setContextProperty("fileHandler", fileHandler);
-    //PfoModel *pfoModel = new PfoModel();
-    //view.rootContext()->setContextProperty("pfoModel",  pfoModel());
+
+    //NetworkHelper *nwHelper = new NetworkHelper();
+    //QNetworkAccessManager *manager = new QNetworkAccessManager();
+    //nwHelper->setNetworkAccessManager(manager);
+    //nwHelper->doWebRequest("", "POST", "https://www.google.com/accounts/ClientLogin", 1);
+    //nwHelper->doWebRequest("", "GET", "http://finance.google.com/finance/feeds/default/portfolios", 0);
+
+    // C++ ListModel
+    //    viewer.rootContext()->setContextProperty("pfoCModel",  createPfoModel);
 
     viewer.setAttribute(Qt::WA_NoSystemBackground);
     viewer.viewport()->setAttribute(Qt::WA_NoSystemBackground);
