@@ -36,6 +36,11 @@ var action = "";
 var tags = "";
 
 var itemsURL = "";
+var gPfoLength;
+
+function returnLength() {
+    return gPfoLength;
+}
 
 function setComponents(mod, pos, wait, err) {
     model   = mod;
@@ -261,7 +266,7 @@ function login(email, password) {
     error.state  = "hidden";
 
     try {
-        waiting.state = "shown";
+        waiting.state = "login";
         var url = "https://www.google.com/accounts/ClientLogin?Email=" + encodeURIComponent(email) + "&Passwd=" + encodeURIComponent(password) + "&service=finance" + "&source=" + encodeURIComponent("stockona");
         doWebRequest("POST", url, 1, parseToken, 0);
     }catch(err) {
@@ -291,24 +296,50 @@ function loadAllPortfolios() {
     loadPortfolio();
 }
 
-function loadOnePosition(posFeedLink) {
-    // Pull both return and transactions info
-    itemsURL = posFeedLink+"?returns=true&transactions=true";
-    //itemsURL = "http://finance.google.com/finance/feeds/default/portfolios/2/positions?returns=true&transactions=true";
-    console.log(itemsURL);
-    loadPosition();
+function loadOnePosition(posFeedLink, pfoLocal, pfoIsYahoo, loadPosFromFile) {
+    console.log("loadOnePosition: " + posFeedLink + " " + pfoLocal + " " + pfoIsYahoo + " " + loadPosFromFile);
+
+    if (pfoLocal) {
+        loadLocalPosition(posFeedLink, pfoIsYahoo, loadPosFromFile);
+    }
+    else {
+        // Pull both return and transactions info
+        // itemsURL = "http://finance.google.com/finance/feeds/default/portfolios/2/positions?returns=true";
+        // itemsURL = posFeedLink+"?returns=true&transactions=true";
+        itemsURL = posFeedLink+"?returns=true";
+        console.log(itemsURL);
+        loadPosition();
+    }
 }
 
 function loadOneQuote(symObj, idx) {
+
     itemsURL = "http://www.google.com/finance/info?client=ig&infotype=infoquoteall&q=" + symObj.symExg + ":" + symObj.symName;
     //console.log(itemsURL);
     loadQuote(symObj, idx);
 }
 
-function loadAllYahooQuote(quoteList) {
-    itemsURL =   "http://download.finance.yahoo.com/d/quotes.csv?s="+ quoteList + "&f=b2b3";
+function loadAllYahooQuote(quoteList, isYahooQuote) {
+    if (isYahooQuote) {
+        // b2, b3: ask, bid (real-time)
+        // g,h,j,k (day lo, day hi, 52w lo 52w hi)
+        // c6: change, k2: change percentage
+        // l1: last trade price
+        // j3: market cap
+        // a2: avg volume (3m), v: volume (real-time)
+        // r2: PE (real-time), r: PE
+        // e7: EPS Estimate Current Year
+        // x: stock exchange
+        // n: name
+        itemsURL =   "http://download.finance.yahoo.com/d/quotes.csv?s="+ quoteList + "&f=b2b3ghjkc6k2l1j3a2vr2e7xn";
+        loadYahooQuote();
+    }
+    else {
+        itemsURL =   "http://download.finance.yahoo.com/d/quotes.csv?s="+ quoteList + "&f=b2b3";
+        loadYahooQuote();
+    }
     //console.log(itemsURL);
-    loadYahooQuote();
+
 }
 
 function loadOnePortfolio(PortfolioName) {
@@ -319,7 +350,7 @@ function loadOnePortfolio(PortfolioName) {
 function loadPortfolio() {
     try {
         model.clear();
-        //pModel.clear();
+        // pModel.clear();
         // Have to set to "portfolio", o.w. stategroup error message
         waiting.state = "shown";
         doWebRequest("GET", itemsURL, 0, parsePortfolio, 1);
@@ -349,9 +380,9 @@ function loadPosition() {
 function loadQuote(symObj, idx) {
     if (idx >= pModel.count) {
         pModel.append({
-                     "idx":            idx,
-                     "id":             symObj.symId,
-                     "rtnYTD":         symObj.symRtnYTD,
+                     //"idx":            idx,
+                     //"id":             symObj.symId,
+                     //"rtnYTD":         symObj.symRtnYTD,
                      "share":          symObj.symShare,
                      "shareCost":      symObj.shareCost,
                      "shareDayGain":   symObj.shareDayGain,
@@ -384,7 +415,6 @@ function loadQuote(symObj, idx) {
 
                      "quoteAsk":       "-",
                      "quoteBid":       "-"
-
         });
     }
     else {
@@ -394,8 +424,8 @@ function loadQuote(symObj, idx) {
             "shareCost":      symObj.shareCost,
             "shareDayGain":   symObj.shareDayGain,
             "shareValue":     symObj.shareValue,
-            "rtnYTD":         symObj.symRtnYTD,
             "shareGainPercent": symObj.shareGainPercent
+            //"rtnYTD":         symObj.symRtnYTD
         });
     }
 
@@ -439,6 +469,7 @@ function parsePortfolio(data) {
         // <openSearch::totalResults>
         var pfoLength = data.childNodes[8].firstChild.nodeValue;
         //console.log("pfo.length="+pfoLength);
+        gPfoLength = pfoLength;
 
         // <entry>
         for (var i=0; i<pfoLength; i++) {
@@ -454,10 +485,7 @@ function parsePortfolio(data) {
             // Push to pfoModel
             if (i<model.count) {
                 model.set(i, {
-                             //"idx": i,
-                             //"etag": pfoEtag,
                              "name": pfoName,
-                             //"id": pfoId,
                              "feedLink": pfoFeedLink,
                              //"currency": currency,
                              //"gainPercent": pfoGainPercent,
@@ -467,16 +495,15 @@ function parsePortfolio(data) {
                 });
             }
             else {
+                //pfoCModel.append(false, false, 0, pfoName, pfoFeedLink, "-");
                 model.append({
-                             //"idx": i,
-                             //"etag": pfoEtag,
                              "local": 0,
                              "name": pfoName,
-                             //"id": pfoId,
                              "feedLink": pfoFeedLink,
                              //"currency": currency,
                              //"gainPercent": pfoGainPercent,
                              //"rtnYTD": pfoRtnYTD,
+                             "isYahoo": false,
                              "excerpt": "-",
                              "num": 0
                 });
@@ -498,21 +525,12 @@ function parsePortfolio(data) {
             console.log("pfo.rtnYTD="+pfoRtnYTD);
             //*/
         }
+
     //}catch(err) {
     //    addError("Error: " + err);
     //}
-        // Push local portfolio
-        var fileOk = fileHandler.loadPfo();
-
-        if (fileOk==0){
-            model.append({
-                         "local": 1,
-                         "name": fileHandler.localPfoName,
-                         "feedLink": "",
-                         "excerpt": "Locally stored portfolio",
-                         "num": 0
-            });
-        }
+        // Load local portfolio
+        loadLocalPortfolio();
 
     waiting.state = "hidden";
 }
@@ -539,6 +557,73 @@ function parsePortfolioNum(data, pfoIdx) {
     }
 }
 
+// Local
+function loadLocalPortfolio() {
+
+    var fileOk = fileHandler.loadPfo();
+
+    if (fileOk==0){
+        for (var i=0; i < fileHandler.localPfoName.length; i++) {
+            model.append({
+                         "local": 1,
+                         "name": fileHandler.localPfoName[i],
+                         "feedLink": "",
+                         "excerpt": fileHandler.localPfoDesc[i],
+                         "isYahoo": fileHandler.localPfoIsYahoo[i],
+                         "num": fileHandler.localPfoNum[i]
+            });
+        }
+    }
+    else {
+        error.reason = "Cannot load local portfolio.";
+        error.state = "shown";
+    }
+}
+
+function loadLocalPosition(pfoIdx, pfoIsYahoo, loadPosFromFile) {
+
+    var fileOk = 0;
+
+    if (loadPosFromFile) {
+        fileOk = fileHandler.loadPos(pfoIdx);
+    }
+
+    var quoteList = "";
+
+    if (fileOk==0) {
+        for (var i=0; i<fileHandler.localPosSymbol.length; i++) {
+            console.log(i + ":" + fileHandler.localPosSymbol[i]);
+
+            var symObj = {
+                "symName": fileHandler.localPosSymbol[i],
+                "symExg": fileHandler.localPosExg[i],
+                "symShare": fileHandler.localPosShare[i],
+                "shareCost": fileHandler.localPosCost[i],
+                "shareDayGain": 0,
+                "shareGain": 0,
+                "shareValue": 0,
+                "shareGainPercent": 0
+            };
+
+            if (!pfoIsYahoo) {
+                loadOneQuote(symObj, i);
+            }
+            quoteList = quoteList + "+" + convertExchangeForYahoo(symObj.symName, symObj.symExg);
+        }
+
+        // Take out leading +
+        quoteList = quoteList.replace(/^\+/, "");
+        loadAllYahooQuote(quoteList, pfoIsYahoo);
+
+    }
+    else {
+        error.state = "shown";
+        error.reason = "Cannot load position file " + pfoIdx + ".pos";
+    }
+
+    waiting.state = "hidden";
+}
+
 function parsePosition(data) {
     //try {
         // 2) XML DOM
@@ -598,9 +683,10 @@ function parsePosition(data) {
         */
         for (var i=0; i<posLength; i++) {
             // Transaction data
-            var txLength =data.childNodes[10+i].childNodes[5].firstChild.childNodes[6].firstChild.nodeValue;
+            //var txLength =data.childNodes[10+i].childNodes[5].firstChild.childNodes[6].firstChild.nodeValue;
 
             // Catch-ya: when there is tx record available, the first gf transactiondata node becomes the date
+            /*
             for (var j=0; j<txLength; j=j+1) {
                 // Check attribute number
                 var txTxDataAttLength = data.childNodes[10+i].childNodes[5].firstChild.childNodes[8+j].childNodes[5].attributes.length;
@@ -619,6 +705,7 @@ function parsePosition(data) {
                     "txComUnit"     : data.childNodes[10+i].childNodes[5].firstChild.childNodes[8+j].childNodes[5].childNodes[0].firstChild.attributes[1].nodeValue
             };
 
+
 //                console.log("####="+symObj.symName);
 //                console.log("txLength "     +   txLength   );
 //                console.log("txAttLength "  +   txTxDataAttLength);
@@ -629,6 +716,7 @@ function parsePosition(data) {
 //                console.log(" txCom "       +  txObj.txCom      );
 //                console.log(" txComUnit "   +  txObj.txComUnit  );
             }
+            */
 
             var symObj = {
                 //"symId"          : data.childNodes[10+i].childNodes[0].firstChild.nodeValue,
@@ -682,7 +770,7 @@ function parsePosition(data) {
 
         // Take out leading +
         quoteList = quoteList.replace(/^\+/, "");
-        loadAllYahooQuote(quoteList);
+        loadAllYahooQuote(quoteList, 0);
 
     //}catch(err) {
     //    addError("Error: " + err);
@@ -692,15 +780,6 @@ function parsePosition(data) {
 
 // There is a Yahoo real-time feed!
 function parseCSV(data) {
-    /*
-      Ask: b2
-      Bid: b3
-      Ask size: a5
-      Bid size: b6
-      After Hours Change (Real-time): c8 (broken?)
-      d: dividend per share (inconsistent with GF)
-      y: dividend yield (inconsistent with GF)
-    */
     // Array[Row][Column]
     //console.log(data);
     var csvObj = CSVToArray(data);
@@ -710,12 +789,109 @@ function parseCSV(data) {
         return;
     }
     else {
-        for (var i=0; i<pModel.count; i=i+1) {
-            //console.log(i+":(Ask,Bid) = "+csvObj[i][0] + "/" + csvObj[i][1])
-            pModel.set(i, {
-                       "quoteAsk": (csvObj[i][0]=="N/A") ? "-" : csvObj[i][0],
-                       "quoteBid": (csvObj[i][1]=="N/A") ? "-" : csvObj[i][1]
-        });
+        // b2, b3: ask, bid (real-time)
+        if (csvObj[0].length==2) {
+            for (var i=0; i<pModel.count; i=i+1) {
+                //console.log(i+":(Ask,Bid) = "+csvObj[i][0] + "/" + csvObj[i][1])
+                pModel.set(i, {
+                           "quoteAsk": (csvObj[i][0]=="N/A") ? "-" : csvObj[i][0],
+                           "quoteBid": (csvObj[i][1]=="N/A") ? "-" : csvObj[i][1]
+                });
+            }
+        }
+        // b2, b3: ask, bid (real-time)
+        // g,h,j,k (day lo, day hi, 52w lo 52w hi)
+        // c6: change, k2: change percentage
+        // l1: last trade price
+        // j3: market cap
+        // a2: avg volume (3m), v: volume (real-time)
+        // r2: PE (real-time), r: PE
+        // e7: EPS Estimate Current Year
+        // x: stock exchange
+        // n: name
+        else {
+             for (var i=0; i<fileHandler.localPosSymbol.length; i=i+1) {
+                 var change = csvObj[i][7];
+
+                 var quoteChgColor;
+                 if (change.match(/\+/)=="+") {
+                     quoteChgColor = "green";
+                     //shareCost = formatNumber(shareValue/(1+parseFloat(gainPtg)));
+                 }
+                 else {
+                     quoteChgColor = "red";
+                     //shareCost = formatNumber(shareValue/(1-parseFloat(gainPtg)));
+                 }
+
+                 // Split string
+                 change = change.split(" - ");
+                 change[1] = change[1].substr(0, change[1].indexOf("%"));
+
+                 if (pModel.count==0) {
+                        pModel.append({
+                             "exchange":   (csvObj[i][14]=="N/A") ? "-" : csvObj[i][14],
+                             "fullName":   (csvObj[i][15]=="N/A") ? "-" : csvObj[i][15],
+                             "name":         fileHandler.localPosSymbol[i],
+                             "share":        fileHandler.localPosShare[i],
+                             "shareGain":    0,
+                             "shareCost":    fileHandler.localPosCost[i],
+                             "shareDayGain": 0,
+                             "shareValue":   0,
+                             "shareGainPercent": 0,
+
+                             "quoteAsk":   (csvObj[i][0]=="N/A") ? "-" : csvObj[i][0],
+                             "quoteBid":   (csvObj[i][1]=="N/A") ? "-" : csvObj[i][1],
+                             "quotePrice": (csvObj[i][8]=="N/A") ? "-" : csvObj[i][8],
+                             "quoteChgColor": quoteChgColor,
+
+                             "quoteChg":   (change[0]=="N/A") ? "-" : change[0],
+                             "quoteChgPtg":(change[1]=="N/A") ? "-" : change[1],
+                             "quoteVol":   (csvObj[i][11]=="N/A") ? "-" : csvObj[i][11],
+                             "quoteAvgVol":(csvObj[i][10]=="N/A") ? "-" : csvObj[i][10],
+                             "quoteMktCap":(csvObj[i][9]=="N/A") ? "-" : csvObj[i][9],
+                             "quoteDayHi": (csvObj[i][3]=="N/A") ? "-" : csvObj[i][3],
+                             "quoteDayLo": (csvObj[i][2]=="N/A") ? "-" : csvObj[i][2],
+                             "quote52wHi": (csvObj[i][5]=="N/A") ? "-" : csvObj[i][5],
+                             "quote52wLo": (csvObj[i][4]=="N/A") ? "-" : csvObj[i][4],
+                             "quoteEps":   (csvObj[i][13]=="N/A") ? "-" : csvObj[i][13],
+                             "quoteBeta":   "-",
+                             "quotePe":    (csvObj[i][12]=="N/A") ? "-" : csvObj[i][12],
+                             "quoteType":   "-"
+                        });
+                 }
+                 else {
+                     pModel.set(i, {
+                                "exchange":   (csvObj[i][14]=="N/A") ? "-" : csvObj[i][14],
+                                "fullName":   (csvObj[i][15]=="N/A") ? "-" : csvObj[i][15],
+                                "name":         fileHandler.localPosSymbol[i],
+                                "share":        fileHandler.localPosShare[i],
+                                "shareGain":    0,
+                                "shareCost":    fileHandler.localPosCost[i],
+                                "shareDayGain": 0,
+                                "shareValue":   0,
+                                "shareGainPercent": 0,
+
+                                "quoteAsk":   (csvObj[i][0]=="N/A") ? "-" : csvObj[i][0],
+                                "quoteBid":   (csvObj[i][1]=="N/A") ? "-" : csvObj[i][1],
+                                "quotePrice": (csvObj[i][8]=="N/A") ? "-" : csvObj[i][8],
+                                "quoteChgColor": quoteChgColor,
+
+                                "quoteChg":   (change[0]=="N/A") ? "-" : change[0],
+                                "quoteChgPtg":(change[1]=="N/A") ? "-" : change[1],
+                                "quoteVol":   (csvObj[i][11]=="N/A") ? "-" : csvObj[i][11],
+                                "quoteAvgVol":(csvObj[i][10]=="N/A") ? "-" : csvObj[i][10],
+                                "quoteMktCap":(csvObj[i][9]=="N/A") ? "-" : csvObj[i][9],
+                                "quoteDayHi": (csvObj[i][3]=="N/A") ? "-" : csvObj[i][3],
+                                "quoteDayLo": (csvObj[i][2]=="N/A") ? "-" : csvObj[i][2],
+                                "quote52wHi": (csvObj[i][5]=="N/A") ? "-" : csvObj[i][5],
+                                "quote52wLo": (csvObj[i][4]=="N/A") ? "-" : csvObj[i][4],
+                                "quoteEps":   (csvObj[i][13]=="N/A") ? "-" : csvObj[i][13],
+                                "quoteBeta":   "-",
+                                "quotePe":    (csvObj[i][12]=="N/A") ? "-" : csvObj[i][12],
+                                "quoteType":   "-"
+                     });
+                 }
+             }
         }
     }
 }
@@ -824,42 +1000,12 @@ function convertExchangeForYahoo (name, exg) {
     else if (exg=="SHA")              { return (name + "." + "SS"); }
     else if (exg=="SHE")              { return (name + "." + "SZ"); }
     else if (exg=="SEO")              { return (name + "." + "KS"); }
-    else                              { return "NULL"; }
+    else                              { return name; }
 }
 
-function getNodeValue(node, name) {
-    var nodeValue = "";
-    for(var i=0; i<node.childNodes.length; i++) {
-        var nodeName = node.childNodes[i].nodeName;
-        if(nodeName==name) {
-            nodeValue = node.childNodes[i].firstChild.nodeValue;
-        }
-    }
-    return nodeValue;
-}
-
-function formatNumber(data) {
-    // > 1M: Display M
-    // > 10k: Display K
-    var tmp;
-    if (Number(data)>1000000) {
-        tmp = sprintf("%.2f", Number(data)/1000000);
-        return tmp + "m";
-    }
-    else if (Number(data)>10000) {
-        tmp = sprintf("%.2f", Number(data)/10000);
-        return tmp + "k";
-    }
-    else {
-        return sprintf("%.2f", Number(data));
-    }
-}
-
-function removeLinks(original) {
-    var txt = original;
-    txt = txt.replace(/<a /g, "<span ");
-    txt = txt.replace(/<\/a>/g, "</span>");
-    return txt;
+function removeComment(data) {
+    data = data.replace(/\/\//, "");
+    return data;
 }
 
 // function from http://forums.devshed.com/t39065/s84ded709f924610aa44fff827511aba3.html
@@ -957,6 +1103,42 @@ function sprintf()
    return str;
 }
 
+/*
+function getNodeValue(node, name) {
+    var nodeValue = "";
+    for(var i=0; i<node.childNodes.length; i++) {
+        var nodeName = node.childNodes[i].nodeName;
+        if(nodeName==name) {
+            nodeValue = node.childNodes[i].firstChild.nodeValue;
+        }
+    }
+    return nodeValue;
+}
+
+function formatNumber(data) {
+    // > 1M: Display M
+    // > 10k: Display K
+    var tmp;
+    if (Number(data)>1000000) {
+        tmp = sprintf("%.2f", Number(data)/1000000);
+        return tmp + "m";
+    }
+    else if (Number(data)>10000) {
+        tmp = sprintf("%.2f", Number(data)/10000);
+        return tmp + "k";
+    }
+    else {
+        return sprintf("%.2f", Number(data));
+    }
+}
+
+function removeLinks(original) {
+    var txt = original;
+    txt = txt.replace(/<a /g, "<span ");
+    txt = txt.replace(/<\/a>/g, "</span>");
+    return txt;
+}
+
 function prettyDate(date){
     try {
         var diff = (((new Date()).getTime() - date.getTime()) / 1000);
@@ -1026,7 +1208,5 @@ function parseDate(stamp)
     }
 }
 
-function removeComment(data) {
-    data = data.replace(/\/\//, "");
-    return data;
-}
+
+*/
